from pathlib import Path


class Track:
    def __init__(self, location: Path):
        self.path = location

    def __str__(self):
        return str(self.path)

    @property
    def filename(self) -> str:
        return self.path.name

    @property
    def stem(self) -> str:
        return self.path.stem

    @property
    def extension(self) -> str:
        return self.path.suffix

    @property
    def artist(self) -> Path:
        return self.path.parent.parent

    @property
    def album(self) -> Path:
        return self.path.parent

    def artist_output(self, root: Path) -> Path:
        return root / self.artist.parts[-1]

    def album_output(self, root: Path) -> Path:
        return root / self.artist.parts[-1] / self.album.parts[-1]

    def output_file(self, root: Path, extension: str) -> Path:
        return root / self.artist.parts[-1] / self.album.parts[-1] / f"{self.stem}.{extension}"
